pub fn capture_window_frame(platform: &impl CapturePlatform) -> Option<CGRect>Expand description
Reads the currently focused window frame from the platform without running text capture.
pub fn capture_window_frame(platform: &impl CapturePlatform) -> Option<CGRect>Reads the currently focused window frame from the platform without running text capture.